@@ -14,19 +14,15 @@
 #' # "1970-01-01 GMT"
 origin <- structure(0, class = c("POSIXt", "POSIXct"))
 
-#' define valid units for time objects
-#' 
-#' With no argument, the functions return a factor containing
-#' the valid time units. With an argument, it returns the units 
-#' asked for.
-#' @param x a character string representing the needed units
-#' @param \dots arguments to or from other methods
 POSIXt.units <- function(x=NULL, ...) {
-	availables.units <- c('second', 'minute', 'hour', 'day', 'week', 'month', 'year', 'AD')
-	if (is.null (x))
-		return (factor (availables.units, availables.units, ordered = TRUE) ) else
-		# return (factor (availables.units[c(1:4, 6:7)], availables.units, ordered = TRUE) ) else
-	return (factor (x, availables.units, ordered=TRUE) )
+	availables.units <- c('second', 'minute', 'hour', 'day',
+			      'week', 'month', 'year', 'AD')
+	if(is.null( x ))
+		return(factor(availables.units, availables.units,
+			      ordered = TRUE) ) else
+		return (factor (x, availables.units, ordered=TRUE) )
+	      # return (factor (availables.units[c(1:4, 6:7)],
+	      # availables.units, ordered = TRUE) ) else
 }
 
 #' define generic function to compare anything to a numeric
